import React, {useState} from 'react'
import {TextField, Avatar, Button} from '@mui/material'


const PDFEmbed = ({pdfUrl}) => { 
    return (<embed
        src={pdfUrl}
        type="application/pdf"
        style={{width: '100%', height: '100%'}}
        title="PDF Viewer"
    />)
}

export function App() {
    const [inputValue, setInputValue] = useState('')
    const [pin, setPin] = useState('')

    const handleInputChange = (event) => {
        setInputValue(event.target.value)
    }

    const handlePinChange = (event) => {
        setPin(event.target.value)
    }

    const handleSubmit = async () => {
        if (!inputValue || !pin) {
            alert('Both fields are required');
            return;
        }

        const data = {
            fullName: inputValue, password: pin,
        }

        try {
            const response = await fetch('http://localhost:8095/api/v1/sign', {
                method: 'POST', headers: {
                    'Content-Type': 'application/json',
                }, body: JSON.stringify(data),
            })

            if (response.ok) {
                const result = await response.json()
                alert("Successfully signed the Document!")
            } else {
                alert("An error occurred (Check your submitted Data!)")
            }
        } catch (error) {
            console.error('Error:', error)
        }
    }

    const pdfUrl = 'https://dagrs.berkeley.edu/sites/default/files/2020-01/sample.pdf'

    return (<div style={{display: 'flex', flexDirection: 'column', height: '98vh'}}>
        <div style={{padding: '1rem', display: 'flex', alignItems: 'center', justifyContent: 'center'}}>
            <Avatar>{inputValue.charAt(0).toUpperCase()}</Avatar>
        </div>

        <div style={{padding: '1rem', display: 'flex', alignItems: 'center', justifyContent: 'center'}}>
            <TextField
                required
                id="fullname"
                label="Full Legal Name"
                name="fullname"
                autoComplete="name"
                value={inputValue}
                onChange={handleInputChange}
                style={{marginRight: '1rem', flex: 1}}
            />
            <TextField
                required
                id="Pin"
                label="Password"
                name="password"
                autoComplete="one-time-code"
                value={pin}
                onChange={handlePinChange}
                style={{marginRight: '1rem', flex: 1, maxWidth: '20%'}}
            />
            <Button variant="contained" onClick={handleSubmit}>Sign</Button>
        </div>

        <div style={{flex: 1, overflow: 'hidden'}}>
            <PDFEmbed pdfUrl={pdfUrl}/>
        </div>
    </div>)
}

export default App
